@@ -24,9 +24,10 @@ Then, restart your JupyterLab instance, and refresh your browser. Mito should no
 NOTE: if you have any issues with installation, please email book a demo time at https://hubs.ly/H0FL1920
 """
 
+from mitosheet.mito_analytics import log
 import os
 import pandas as pd
-from mitosheet.user.user import initialize_user, is_local_deployment
+from mitosheet.user import initialize_user
 from mitosheet.example import MitoWidget, sheet
 from mitosheet.save_utils import register_analysis
 from mitosheet.errors import CreationError, EditError
@@ -40,6 +41,7 @@ from mitosheet.sheet_functions.types import *
 
 # Make sure the user is initalized
 initialize_user()
+log('imported_mitosheet')
 
 # This function is only necessary for mitosheet3, as it is used
 # in jlab3 to find the extension. It is not used in jlab2
