@@ -29,6 +29,12 @@ BAR_CHART_MAX_NUMBER_OF_ROWS = 5_000
 BOX_PLOT_3_SERIES_MAX_NUMBER_OF_ROWS = 500_000
 BOX_PLOT_4_SERIES_MAX_NUMBER_OF_ROWS = 250_000
 
+# On the key axis, the difference between the minimum value and the maximum
+# value initially displayed on the graph can be no larger than STARTING_RANGE_RANGE
+# for qualifying graphs. Only scatter plots and bar charts with a key series that is 
+# a number have the default starting range updated. 
+STARTING_RANGE_MAX_RANGE = 500
+
 # Labels used to show that the graph is filtered. 
 # Used both in the graph_title and the title.
 # Note: Because box plot filtering is more complicated, we don't 
@@ -62,7 +68,7 @@ def is_all_number_series(df, column_headers):
             return False
     return True
 
-def get_graph_title (x_axis_column_headers, y_axis_column_headers, filtered, graph_type):
+def get_graph_title (x_axis_column_headers, y_axis_column_headers, filtered, graph_type, special_title=None):
     """
     Helper function for determing the title of the graph for the scatter plot and bar chart
     """
@@ -80,7 +86,7 @@ def get_graph_title (x_axis_column_headers, y_axis_column_headers, filtered, gra
     # Compile all of the column headers into one comma separated string
     all_column_headers = (', ').join(x_axis_column_headers + y_axis_column_headers)
     # Get the title of the graph based on the type of graph
-    graph_title_label = GRAPH_TITLE_LABELS[graph_type]
+    graph_title_label = GRAPH_TITLE_LABELS[graph_type] if special_title is None else special_title
     # Combine all of the non empty graph title components into one list
     graph_title_components = [all_column_headers, graph_filter_label, graph_title_label] if graph_filter_label is not None else [all_column_headers, graph_title_label]
     
@@ -118,6 +124,90 @@ def get_graph_labels(x_axis_column_headers, y_axis_column_headers):
 
     return x_axis_title, y_axis_title
 
+def get_starting_ranges(graph_type, df, x_axis_column_headers, y_axis_column_headers):
+    """
+    Helper function for determing range that the axis should default to on 
+    inital render. It finds the smallest value in the key series and sets the range of it
+    [smallest value in series, smallest value in series + STARTING_RANGE_RANGE]
+
+    It returns the object {
+        X: [start of range, end of range] or [None, None]
+        Y: [start of range, end of range] or [None, None]
+    }
+
+    At least one of the axises will be [None, None]
+    
+    In the following conditions, this function will return a range of [None, None] so 
+    as to not overwrite the plotly default:
+    1. the graph type is not a scatter plot or a bar chart.
+    2. the key series is not a NUMBER_SERIES.
+    3. the range of the key series is already less than STARTING_RANGE_RANGE.
+
+    This approach is used to avoid graphs rendering where the data is nearly invisible due to the 
+    range of the key axis being so large
+    """
+    if (graph_type != SCATTER and graph_type != BAR) or (x_axis_column_headers == [] and y_axis_column_headers == []):
+        # We only need to overwrite the default range in scatter plots and bar charts. 
+        # We also don't care about the case where the graph has no data.
+        return {
+            X: [None, None],
+            Y: [None, None]
+        } 
+
+    elif len(x_axis_column_headers) == 0 and len(y_axis_column_headers) > 0:
+        key_axis = Y
+        # Since the user has no way of zooming in/out the y axis, we regretably 
+        # don't start the graph zoomed in because they will be stuck there!
+        return {
+            X: [None, None],
+            Y: [None, None]
+        } 
+
+    elif len(x_axis_column_headers) > 0 and len(y_axis_column_headers) == 0:
+        # In this case the x axis is the key axis and it is the index series. 
+        # Because the index series is always a number, we don't have to do the 
+        # mito_type_check and we just make sure that there are more than 
+        # DEFAULT_RANGE rows. 
+        key_axis = X
+        return {
+            X: [0, STARTING_RANGE_MAX_RANGE] if len(df) > STARTING_RANGE_MAX_RANGE else [None, None],
+            Y: [None, None]
+        }
+
+    else: 
+        key_axis = X if len(x_axis_column_headers) == 1 else Y
+        key_series = df[x_axis_column_headers[0]] if key_axis == X else df[y_axis_column_headers[0]]
+
+        # If the series is not a number series, we give up on creating
+        # a heuristic for setting the x axis 
+        # TODO: Figure out if we can set the range as a list of the first 500 unique values
+        # Think about whether the order of the unique values in the chart matters. 
+        if get_mito_type(key_series) != NUMBER_SERIES:
+            return {
+                X: [None, None],
+                Y: [None, None]
+            } 
+
+        # Learn about the range of the key series to make decision
+        # about how we should set the default range of the graph
+        min_value_in_series = key_series.min()
+        max_value_in_series = key_series.max()
+
+        if max_value_in_series - min_value_in_series > STARTING_RANGE_MAX_RANGE:
+            # If the range of the series is greater than STARTING_RANGE_RANGE, then 
+            # set the starting range from the min_value_in_series to min_value_in_series + STARTING_RANGE_RANGE
+            return {
+                X: [min_value_in_series, min_value_in_series + STARTING_RANGE_MAX_RANGE] if key_axis == X else [None, None],
+                Y: [None, None] # the Y axis is never set zoomed in because the user has no way of zooming out
+            }
+        else:
+            # If the range of the series is less than STARTING_RANGE_RANGE, 
+            # don't overwrite plotly's default range
+            return {
+                X: [None, None],
+                Y: [None, None]
+            } 
+
 def filter_df_to_top_unique_values_in_series(
         df: pd.DataFrame,
         main_series: pd.Series,
@@ -187,6 +277,8 @@ def get_bar_chart(df, x_axis_column_headers, y_axis_column_headers):
     Returns a bar chart using the following heuristic:
     - Graphs the first BAR_CHART_MAX_NUMBER_OF_ROWS rows. 
 
+    If only one axis has data, then we create a histogram instead. 
+
     If at leastat least the x_axis_column_headers or y_axis_column_headers 
     has at least one series, then it returns a bar chart. Otherwise, it returns 
     a blank graph.
@@ -200,9 +292,19 @@ def get_bar_chart(df, x_axis_column_headers, y_axis_column_headers):
     if not x_axis and not y_axis:
         # This should never happen because this check already occurs in the get_graph
         # function. But we leave it here for robustness of the function
-        return go.Figure()
+        return go.Figure(), False
 
-    # Sort the key column in decreasing frequency
+    # If only one axis is supplied, then we create a histogram instead of a bar chart 
+    # because it is more informative to show the counts of each value instead of graphing 
+    # the values by index. 
+    if x_axis and not y_axis:
+        return get_histogram(X, df, x_axis_column_headers)
+    elif y_axis and not x_axis:
+        return get_histogram(Y, df, y_axis_column_headers)
+
+    # If both axises are supplied, then we go on to create the bar chart. 
+    # Start by sorting the key column in decreasing frequency so we can filter 
+    # dataframe according to the bar chart filtering strategy. 
     if len(y_axis_column_headers) == 1:
         df['Frequency'] = df.groupby(y_axis_column_headers[0])[y_axis_column_headers[0]].transform('count')
     else:
@@ -222,26 +324,8 @@ def get_bar_chart(df, x_axis_column_headers, y_axis_column_headers):
     # unlike the other types of graphs where we can use the add_trace function.
     traces = []
 
-    # If the x_axis has at least one series and the y_axis has no series
-    if x_axis and not y_axis:
-        for column_header in x_axis_column_headers:
-            traces.append(
-                go.Bar( 
-                    y = df[column_header],
-                    name=(' ').join([column_header, filter_label])
-                )
-            )
-    # If the y_axis has at least one series and the x_axis has no series
-    elif y_axis and not x_axis:
-        for column_header in y_axis_column_headers:
-            traces.append(
-                go.Bar( 
-                    x = df[column_header],
-                    name=(' ').join([column_header, filter_label])
-                )
-            )
     # If the y_axis has __exactly__ one series and the x_axis has __at least__ one series (covered by above checks)
-    elif len(y_axis_column_headers) == 1:
+    if len(y_axis_column_headers) == 1:
         for column_header in x_axis_column_headers:
             traces.append(
                 go.Bar( 
@@ -260,19 +344,28 @@ def get_bar_chart(df, x_axis_column_headers, y_axis_column_headers):
                     name=(' ').join([column_header, filter_label])
                 )
             )
-
-    # Actually create the graph
+    
     fig = go.Figure(data=traces)
 
+    # Update the layout of the graph
     x_axis_title, y_axis_title = get_graph_labels(x_axis_column_headers, y_axis_column_headers)
     graph_title = get_graph_title(x_axis_column_headers, y_axis_column_headers, filtered, BAR)
-
-
     fig.update_layout(
         xaxis_title = x_axis_title,
         yaxis_title = y_axis_title,
         title = graph_title,
-        barmode='group'
+        barmode='group',
+    )
+
+    # Update the starting range of the graph
+    ranges = get_starting_ranges(BAR, df, x_axis_column_headers, y_axis_column_headers)
+    fig.update_layout(
+        xaxis=dict(
+            range=ranges[X]
+        ), 
+        yaxis=dict(
+            range=ranges[Y]
+        )
     )
 
     log(f'generate_graph', {
@@ -284,7 +377,9 @@ def get_bar_chart(df, x_axis_column_headers, y_axis_column_headers):
         'params_filtered': filtered
     })
 
-    return fig
+    # Determine if the graph was zoomed in
+    is_zoomed = ranges[X][0] is not None or ranges[X][1] or ranges[Y][0] is not None or ranges[Y][1] is not None
+    return fig, is_zoomed
 
 def get_box_plot(axis, df, column_headers): 
     """
@@ -307,7 +402,7 @@ def get_box_plot(axis, df, column_headers):
             'params_column_headers': column_headers,
             'params_failed_reason': 'non-number-series'
         })
-        return go.Figure()
+        return go.Figure(), False
       
     filtered = False
 
@@ -351,9 +446,9 @@ def get_box_plot(axis, df, column_headers):
         'params_filtered': filtered
     })
     
-    return fig
+    return fig, False
 
-def get_histogram(axis, df, column_headers):
+def get_histogram(axis, df, column_headers, frequency_title=None):
     """
     Returns a histogram using the following heuristic:
 
@@ -363,18 +458,6 @@ def get_histogram(axis, df, column_headers):
     """
     fig = go.Figure()
 
-    # Make sure all of the series are number_series
-    if not is_all_number_series(df, column_headers):
-        # If not all of the series are numbers, then 
-        # return a blank graph
-        log(f'failed_generate_graph', {
-            'params_graph_type': HISTOGRAM,
-            'params_axis': axis,
-            'params_column_headers': column_headers,
-            'params_failed_reason': 'non-number-series'
-        })
-        return go.Figure()
-
     for column_header in column_headers:
         if axis == X:
             fig.add_trace(go.Histogram(x=df[column_header], name=column_header))
@@ -391,10 +474,10 @@ def get_histogram(axis, df, column_headers):
                 yaxis_title = column_headers[0]
             )
 
-    graph_title = get_graph_title(column_headers, [], False, HISTOGRAM)
+    graph_title = get_graph_title(column_headers, [], False, HISTOGRAM, 'frequencies')
     fig.update_layout(
         title = graph_title,
-        barmode='stack'
+        barmode='group'
     )
 
     log(f'generate_graph', {
@@ -403,7 +486,7 @@ def get_histogram(axis, df, column_headers):
         'params_column_headers': column_headers,
     })
 
-    return fig
+    return fig, False
 
 def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
     """
@@ -422,7 +505,7 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
     if not x_axis and not y_axis:
         # This should never happen because this check already occurs in the get_graph
         # function. But we leave it here for robustness of the function
-        return go.Figure()
+        return go.Figure(), False
 
     # Check the type of each series to appropriately filter 
     all_column_headers = x_axis_column_headers + y_axis_column_headers
@@ -485,15 +568,26 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
                 name=(' ').join([column_header, filter_label])
             ))
 
+    # Update the layout of the graph
     x_axis_title, y_axis_title = get_graph_labels(x_axis_column_headers, y_axis_column_headers)
     graph_title = get_graph_title(x_axis_column_headers, y_axis_column_headers, filtered, SCATTER)
-
     fig.update_layout(
         xaxis_title = x_axis_title,
         yaxis_title = y_axis_title,
         title = graph_title,
     )
 
+    # Update the starting range of the graph
+    ranges = get_starting_ranges(BAR, df, x_axis_column_headers, y_axis_column_headers)
+    fig.update_layout(
+        xaxis=dict(
+            range=ranges[X]
+        ), 
+        yaxis=dict(
+            range=ranges[Y]
+        )
+    )
+
     log(f'generate_graph', {
         'params_graph_type': SCATTER,
         'params_x_axis_column_headers': x_axis_column_headers,
@@ -502,8 +596,10 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
         'params_y_axis_column_types': [get_mito_type(df[column_header]) for column_header in y_axis_column_headers] if y_axis_column_headers is not None else [],
         'params_filtered': filtered
     })
-            
-    return fig
+
+    # Determine if the graph was zoomed in
+    is_zoomed = ranges[X][0] is not None or ranges[X][1] or ranges[Y][0] is not None or ranges[Y][1] is not None
+    return fig, is_zoomed
 
 
 def get_column_summary_graph(axis, df, axis_data_array):
@@ -551,7 +647,9 @@ def get_column_summary_graph(axis, df, axis_data_array):
         'param_filtered': filtered
     })
 
-    return fig
+    # Because the Column Summary Stat Graph is never zoomed in 
+    # we always return False as the second parameter
+    return fig, False
 
 def get_graph(send, event, wsc):
     """
@@ -635,17 +733,17 @@ def get_graph(send, event, wsc):
 
         # Handle the graphs in alphabetical order
         if graph_type == BAR:
-            fig = get_bar_chart(df, x_axis_column_headers, y_axis_column_headers)
+            fig, is_zoomed = get_bar_chart(df, x_axis_column_headers, y_axis_column_headers)
         elif graph_type == BOX:
             # Box plots are only defined on one axis. The UI should enforce that 
             # it is never the case that a box plot is selected with series for both 
             # the x and y axis. However, if it does happen, we default to taking the x axis. 
             if x_axis:
-                fig = get_box_plot(
+                fig, is_zoomed = get_box_plot(
                     X, df, x_axis_column_headers
                 )
             else:
-                fig = get_box_plot(
+                fig, is_zoomed = get_box_plot(
                     Y, df, y_axis_column_headers
                 )
         elif graph_type == HISTOGRAM:
@@ -653,16 +751,16 @@ def get_graph(send, event, wsc):
             # it is never the case that a histogram is selected with series for both 
             # the x and y axis. However, if it does happen, we default to taking the x axis. 
             if x_axis:
-                fig = get_histogram(X, df, x_axis_column_headers)
+                fig, is_zoomed = get_histogram(X, df, x_axis_column_headers)
             else:
-                fig = get_histogram(Y, df, y_axis_column_headers)
+                fig, is_zoomed = get_histogram(Y, df, y_axis_column_headers)
         elif graph_type == SCATTER:
-            fig = get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers)
+            fig, is_zoomed = get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers)
         elif graph_type == SUMMARY_STAT:
             # We handle summary stats separately from the histogram, for now, because 
             # we only let the user use a histogram with all numeric data, whereas the column
             # summary stats may not be all numeric data. 
-            fig = get_column_summary_graph(
+            fig, is_zoomed = get_column_summary_graph(
                 X, df, x_axis_column_headers
             )
             
@@ -679,9 +777,9 @@ def get_graph(send, event, wsc):
             xaxis=dict(
                 rangeslider=dict(
                     visible=True
-                )
+                ),
             ),
-            colorway =["#FF0202", "#03AA00", "#FFA800", "#0085FF"]
+            colorway =["#FF0202", "#03AA00", "#FFA800", "#0085FF"],
         )
 
         # Make the rangeslider take up 5% of the height of the plot space
@@ -689,14 +787,17 @@ def get_graph(send, event, wsc):
             rangeslider_thickness = 0.05
         )
 
-        html_and_script = get_html_and_script_from_figure(
+        return_object = get_html_and_script_from_figure(
             fig, height, width
         )
 
+        # Tell the frontend if the graph is zoomed in
+        return_object['is_zoomed'] = is_zoomed
+
         send({
             'event': 'api_response',
             'id': event['id'],
-            'data': json.dumps(html_and_script)
+            'data': json.dumps(return_object),
         })
 
     except Exception as e:
