@@ -6,7 +6,6 @@
 """
 Main file containing the mito widget.
 """
-from mitosheet.utils import get_new_step_id
 from mitosheet.api import API
 from mitosheet.mito_analytics import log, log_event_processed, log_recent_error
 import pandas as pd
@@ -23,10 +22,8 @@ from mitosheet.save_utils import (
 )
 
 from mitosheet.widget_state_container import WidgetStateContainer
-from mitosheet.profiling import timeit
 
-from mitosheet.user.user import is_local_deployment, should_upgrade_mitosheet, should_display_feedback
-from mitosheet.user.user_utils import get_user_field
+from mitosheet.user import is_local_deployment, should_upgrade_mitosheet, should_display_feedback, get_user_field
 from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
 
 
@@ -291,7 +288,9 @@ def sheet(
                 'params_num_df_args': len([arg for arg in args if isinstance(arg, pd.DataFrame)]),
                 'params_df_index_type': [str(type(arg.index)) for arg in args if isinstance(arg, pd.DataFrame)],
             }
-        )
+        ),
+        # This is the one place where we record the installed packages
+        install_mitosheets_pip_show=True
     )
     
     # If an analysis is passed, we pass this to the widget
