@@ -1,9 +1,3 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
 """
 Mito currently collects logs on basic user interactions with the app, 
 so that we can improve the tool.
@@ -24,15 +18,20 @@ Our general approach to logging can be understood as:
    This appears to be good practice, as it allows us to associate what actions are taken
    with their result very effectively!
 """
+import sys
+import subprocess
+
 from mitosheet.parser import parse_formula
 
 import analytics
 # Write key taken from segement.com
 analytics.write_key = '6I7ptc5wcIGC4WZ0N1t0NXvvAbjRGUgX' 
 
-import sys
-
-from mitosheet.user.user_utils import get_user_field
+from mitosheet.user import (
+    UJ_INTENDED_BEHAVIOR, UJ_STATIC_USER_ID, UJ_USER_SALT, UJ_USER_EMAIL, 
+    UJ_FEEDBACKS, 
+)
+from mitosheet.user import get_user_field, is_local_deployment, is_running_test, is_local_deployment
 from mitosheet._version import __version__
 from mitosheet.errors import get_recent_traceback_as_list
 
@@ -56,7 +55,7 @@ def anonymize_word(word):
     # from the file all the time
     global salt
     if salt is None:
-        salt = get_user_field('user_salt')
+        salt = get_user_field(UJ_USER_SALT)
 
     word = str(word)
 
@@ -81,8 +80,34 @@ def anonymize_formula(formula):
     
     return formula
 
+def get_jupyterlab_version():
+    try:
+        from jupyterlab import __version__ as jupyterlab_version
+    except:
+        jupyterlab_version = 'No JupyterLab'
 
-def log(log_event, params=None):
+    return jupyterlab_version
+
+def get_installed_mitosheets_pip_show():
+    """
+    This gets the version of mitosheet and mitosheet3 that are installed
+    through pip, which allows us to see if the installed version of mitosheet
+    is actually what is running. This allows us to determine if the user has
+    failed to refresh their kernel!
+
+    Because this function can be expensive to run for some users, we should
+    only use this sparingly and not during every log event!
+    """
+    completed_process_mitosheet3 = subprocess.run([sys.executable, '-m', 'pip', 'show', 'mitosheet3'], capture_output=True)
+    all_output = completed_process_mitosheet3.stdout.decode() + completed_process_mitosheet3.stderr.decode()
+    
+    completed_process_mitosheet = subprocess.run([sys.executable, '-m', 'pip', 'show', 'mitosheet'], capture_output=True)
+    all_output += completed_process_mitosheet.stdout.decode() + completed_process_mitosheet.stderr.decode()
+
+    return all_output.splitlines()
+
+
+def log(log_event, params=None, install_mitosheets_pip_show=False):
     """
     Helper function that logs an event with the given parameters. However,
     this function is also responsible for making sure _zero_ private data
@@ -91,9 +116,30 @@ def log(log_event, params=None):
     To accomplish this, we anonymize all data. To do so, we hash this data
     with a private secret that only the user has, making it impossible
     for us to brute force it.
+
+    NOTE: install_mitosheets_pip_show can be an expensive operation for some
+    users, so we should try and minimize where / how we use it!
     """
     if params is None:
         params = {}
+    
+    # Add the python properties to every log event we can
+    python_properties = {
+        'version_python': sys.version_info,
+        'version_jupyterlab': get_jupyterlab_version(),
+        'version_mito': __version__ 
+    }
+    
+    if install_mitosheets_pip_show:
+        pip_shows = get_installed_mitosheets_pip_show()
+    else:
+        pip_shows = []
+
+    params = dict(
+        **params,
+        **python_properties,
+        **{'pip_shows': pip_shows}
+    )
 
     # Private params are where we _make sure_ that no private
     # user data leaves the users machine. We replace any potentially
@@ -147,11 +193,13 @@ def log(log_event, params=None):
         # know that we have some issues here
         private_params['failed_building'] = True
 
-    analytics.track(
-        get_user_field('static_user_id'), 
-        log_event, 
-        private_params
-    )
+    # NOTE: we do not log anything when tests are running
+    if not is_running_test():
+        analytics.track(
+            get_user_field(UJ_STATIC_USER_ID), 
+            log_event, 
+            private_params
+        )
 
 
 def identify():
@@ -159,30 +207,25 @@ def identify():
     Helper function for identifying a user. We just take
     their python version, mito version, and email.
     """
-    # Import here to avoid a circular import
-    from mitosheet.user.user import is_local_deployment
 
-
-    static_user_id = get_user_field('static_user_id')
-    user_email = get_user_field('user_email')
-    intended_behavior = get_user_field('intended_behavior')
-    feedbacks = get_user_field('feedbacks')
+    static_user_id = get_user_field(UJ_STATIC_USER_ID)
+    user_email = get_user_field(UJ_USER_EMAIL)
+    intended_behavior = get_user_field(UJ_INTENDED_BEHAVIOR)
+    feedbacks = get_user_field(UJ_FEEDBACKS)
     local = is_local_deployment()
-
-    try:
-        from jupyterlab import __version__ as jupyterlab_version
-    except:
-        jupyterlab_version = 'No JupyterLab'
+    jupyterlab_version = get_jupyterlab_version()
     
-    analytics.identify(static_user_id, {
-        'python_version': sys.version_info,
-        'mito_version': __version__,
-        'jupyterlab_version': jupyterlab_version,
-        'email': user_email,
-        'local': local,
-        'intended_behavior': intended_behavior,
-        'feedbacks': feedbacks
-    })
+    if not is_running_test():
+        # NOTE: we do not log anything when tests are running
+        analytics.identify(static_user_id, {
+            'version_python': sys.version_info,
+            'version_mito': __version__,
+            'version_jupyterlab': jupyterlab_version,
+            'email': user_email,
+            'local': local,
+            UJ_INTENDED_BEHAVIOR: intended_behavior,
+            UJ_FEEDBACKS: feedbacks
+        })
 
 
 def log_recent_error(log_event=None):
@@ -222,9 +265,6 @@ def log_event_processed(event, widget_state_container, failed=False, edit_error=
     edit error that was thrown during the processing of the event, then edit_error
     should be set to that error.
     """
-    # Import here to avoid a circular import
-    from mitosheet.user.user import is_local_deployment
-
     try:
         # First, we get all the params of the event, and append them with _params_
         event_properties = {
@@ -242,11 +282,7 @@ def log_event_processed(event, widget_state_container, failed=False, edit_error=
             'wsc_curr_step_type': widget_state_container.curr_step['step_type'],
         }
 
-        # Python properties, just for helpful data about the system
-        python_properties = {
-            'version_python': sys.version_info,
-            'version_mito': __version__ 
-        }
+        
 
         if event['type'] == 'replay_analysis_update' or event['type'] == 'save_analysis_update':
             # We log the steps, when the user saves or replays an analysis
@@ -289,7 +325,6 @@ def log_event_processed(event, widget_state_container, failed=False, edit_error=
         log(
             log_event, 
             dict(
-                **python_properties,
                 **event_properties,
                 **wsc_properties,
                 **error_properties
