@@ -54,12 +54,14 @@ def FILLNAN(series: pd.Series, replacement: pd.Series) -> pd.Series:
         ]
     }
     """
-    nan_indexes = series.isna()
+    # Make copy of the series as to not fill the nan values in the series itself
+    series_copy = series.copy(True)
+    nan_indexes = series_copy.isna()
     for idx in range(len(nan_indexes)):
         if nan_indexes[idx]:
-            series[idx] = replacement[0]
+            series_copy[idx] = replacement[0]
 
-    return series
+    return series_copy
 
 
 @handle_sheet_function_errors
