@@ -12,7 +12,7 @@ from typing import Tuple, Union
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types.utils import get_mito_type
+from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, get_mito_type
 
 
 def to_string_series(
@@ -29,13 +29,13 @@ def to_string_series(
     if not from_type.endswith('series'):
         return pd.Series([str(unknown_object)], dtype='str')
 
-    if from_type == 'boolean_series':
+    if from_type == BOOLEAN_SERIES:
         return unknown_object.astype('str')
-    elif from_type == 'datetime_series':
+    elif from_type == DATETIME_SERIES:
         return unknown_object.dt.strftime('%Y-%m-%d %X')
-    elif from_type == 'number_series':
+    elif from_type == NUMBER_SERIES:
         return unknown_object.astype('str')
-    elif from_type == 'string_series':
+    elif from_type == STRING_SERIES:
         # We need to cast here, because object series are treated
         # as string series, and may contain other types
         return unknown_object.astype('str')
