@@ -201,6 +201,11 @@ def values_to_functions_code(values):
 TAB = '    '
 NEWLINE_TAB = f'\n{TAB}'
 
+FLATTEN_COMMENT = '# Flatten the column headers'
+FLATTEN_CODE = f'pivot_table.columns = [{NEWLINE_TAB}\'_\'.join([str(c) for c in col]).strip() if isinstance(col, tuple) else col{NEWLINE_TAB}for col in pivot_table.columns.values\n]'
+RESET_INDEX_COMMENT = '# Reset the column name and the indexes'
+
+
 def build_args_code(
         pivot_rows,
         pivot_columns,
@@ -256,23 +261,21 @@ def transpile_pivot_step(
     transpiled_code = []
     
     # Pivot 
-    pivot_comment = '# Pivot the data'
     pivot_table_args = build_args_code(pivot_rows, pivot_columns, values)
     pivot_table_call = f'pivot_table = {step["df_names"][sheet_index]}.pivot_table({NEWLINE_TAB}{pivot_table_args}\n)'
-    transpiled_code.append(f'{pivot_comment}\n{pivot_table_call}')
+    transpiled_code.append(f'{pivot_table_call}')
 
     # Flatten column headers. 
     # NOTE: this only needs to happen if there is more than one pivot_column, as the columns
     # will be flat if there are no columns pivoted
     if len(pivot_columns) > 0:
-        flatten_comment = '# Flatten the column headers'
-        flatten_code = f'pivot_table.columns = [{NEWLINE_TAB}\'_\'.join([str(c) for c in col]).strip() if isinstance(col, tuple) else col{NEWLINE_TAB}for col in pivot_table.columns.values\n]'
-        transpiled_code.append(f'{flatten_comment}\n{flatten_code}')
+        transpiled_code.append(FLATTEN_COMMENT)
+        transpiled_code.append(FLATTEN_CODE)
 
     # Finially, reset the column name, and the indexes!
-    reset_index_comment = f'# Reset the column name and the indexes'
     reset_index_code = f'{new_df_name} = pivot_table.rename_axis(None, axis=1).reset_index()'
-    transpiled_code.append(f'{reset_index_comment}\n{reset_index_code}')
+    transpiled_code.append(RESET_INDEX_COMMENT)
+    transpiled_code.append(reset_index_code)
 
     return transpiled_code
 
