@@ -1,35 +1,26 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-
 """
 Utilities for creating and initializing the user.json
 file with the current schema
 """
 
-import json
-import os
 from datetime import datetime
-from typing import List, Optional
+from mitosheet.user.utils import is_local_deployment
+from mitosheet.utils import get_random_id
+import os
+import json
 
 from mitosheet._version import __version__
-from mitosheet.user.db import (MITO_FOLDER, USER_JSON_PATH, get_user_field,
-                               set_user_field)
-from mitosheet.user.schemas import (GITHUB_ACTION_EMAIL, GITHUB_ACTION_ID,
-                                    UJ_MITOSHEET_CURRENT_VERSION,
-                                    UJ_MITOSHEET_LAST_FIFTY_USAGES,
-                                    UJ_MITOSHEET_LAST_UPGRADED_DATE,
-                                    UJ_STATIC_USER_ID, UJ_USER_EMAIL,
-                                    USER_JSON_DEFAULT)
+from mitosheet.user.schemas import (
+    UJ_STATIC_USER_ID, UJ_USER_EMAIL, UJ_MITOSHEET_CURRENT_VERSION, 
+    UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES
+)
+from mitosheet.user.schemas import GITHUB_ACTION_EMAIL, GITHUB_ACTION_ID, USER_JSON_DEFAULT
 from mitosheet.user.upgrade import try_upgrade_user_json_to_current_version
-from mitosheet.user.utils import is_local_deployment
+from mitosheet.user.db import MITO_FOLDER, USER_JSON_PATH, get_user_json_object, set_user_field, get_user_field
 
-
-def is_user_json_exists_and_valid_json() -> bool:
+def is_user_json_exists_and_valid_json():
     """
-    Helper function that determines if the current user.json both
+    Helper function that determines if the current user json both
     exists and is valid json
     """
     if not os.path.exists(USER_JSON_PATH):
@@ -43,7 +34,7 @@ def is_user_json_exists_and_valid_json() -> bool:
         return False
 
 
-def try_create_user_json_file() -> None:
+def try_create_user_json_file():
     # Create the mito folder if it does not exist
     if not os.path.exists(MITO_FOLDER):
         os.mkdir(MITO_FOLDER)
@@ -63,7 +54,7 @@ def try_create_user_json_file() -> None:
             set_user_field(UJ_USER_EMAIL, GITHUB_ACTION_EMAIL)
 
 
-def initialize_user(call_identify: bool=True) -> None:
+def initialize_user():
     """
     Internal helper function that gets called every time mitosheet 
     is imported.
@@ -72,9 +63,6 @@ def initialize_user(call_identify: bool=True) -> None:
     1. Creates the user.json if it does not exist (though it usually does, from the installer)
     2. Upgrades the user.json to the most up to date format
     3. Updates the user.json file with any usage or upgrading, logging anything interesting.
-    
-    By default, also identifies the user, but may not do this in some cases (when identify
-    is False), as the user may just be turning logging off or something.
     """
     # Try to create the user.json file, if it does not already exist
     try_create_user_json_file()
@@ -88,7 +76,7 @@ def initialize_user(call_identify: bool=True) -> None:
     # get upgraded on our infrastructure anyways
     mitosheet_current_version = get_user_field(UJ_MITOSHEET_CURRENT_VERSION)
     if mitosheet_current_version != __version__ and is_local_deployment():
-        from mitosheet.telemetry.telemetry_utils import log
+        from mitosheet.mito_analytics import log
         set_user_field(UJ_MITOSHEET_CURRENT_VERSION, __version__)
         set_user_field(UJ_MITOSHEET_LAST_UPGRADED_DATE, datetime.today().strftime('%Y-%m-%d'))
         # Log the upgrade. Note that this runs when the user _actually_ changes
@@ -99,11 +87,8 @@ def initialize_user(call_identify: bool=True) -> None:
 
     # We also note this import as a Mito usage, making sure to only 
     # mark this as usage once per day
-    last_fifty_usages: Optional[List[str]] = get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES)
-    if last_fifty_usages is None: 
-        last_fifty_usages = []
-
-    if last_fifty_usages is not None and len(last_fifty_usages) == 0 or last_fifty_usages[-1] != datetime.today().strftime('%Y-%m-%d'):
+    last_fifty_usages = get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES)
+    if len(last_fifty_usages) == 0 or last_fifty_usages[-1] != datetime.today().strftime('%Y-%m-%d'):
         last_fifty_usages.append(datetime.today().strftime('%Y-%m-%d'))
     # Then, we take the 50 most recent (or as many as there are), and save them
     if len(last_fifty_usages) < 50:
@@ -113,7 +98,5 @@ def initialize_user(call_identify: bool=True) -> None:
     set_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES, most_recent_fifty)
 
     # Reidentify the user, just in case things have changed
-    # but only if we were told to identify
-    if call_identify:
-        from mitosheet.telemetry.telemetry_utils import identify
-        identify()
+    from mitosheet.mito_analytics import identify
+    identify()
