@@ -1,18 +1,16 @@
 """
 Helpers for accessing the user.json file
 """
-from ctypes import Union
 import os
 import json
-from typing import Any, Dict, Optional
 
 # Where all global .mito files are stored
-MITO_FOLDER = os.path.join(os.path.expanduser("~"), '.mito')
+MITO_FOLDER = os.path.expanduser("~/.mito")
 
 # The path of the user.json file
 USER_JSON_PATH = os.path.join(MITO_FOLDER, 'user.json')
 
-def get_user_json_object() -> Optional[Dict[str, Any]]:
+def get_user_json_object():
     """
     Gets the entire user json object
     """
@@ -22,7 +20,7 @@ def get_user_json_object() -> Optional[Dict[str, Any]]:
     except: 
         return None
 
-def get_user_field(field: str) -> Optional[Any]:
+def get_user_field(field):
     """
     Returns the value stored at field in the user.json file,
     but may read a different file if it passed
@@ -33,14 +31,14 @@ def get_user_field(field: str) -> Optional[Any]:
     except: 
         return None
 
-def set_user_json_object(user_json_object: Dict[str, Any]) -> None:
+def set_user_json_object(user_json_object):
     """
     Updates the value of a specific feild in user.json
     """
     with open(USER_JSON_PATH, 'w+') as f:
         f.write(json.dumps(user_json_object))
 
-def set_user_field(field: str, value: Any) -> None:
+def set_user_field(field, value):
     """
     Updates the value of a specific feild in user.json
     """
