@@ -1,24 +1,24 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 """
 Contains functions that are useful for determining the state of the
 current user.
 """
-import getpass
 import os
+import getpass
 from datetime import datetime
-import sys
 
-import pandas as pd
 from mitosheet._version import __version__
 from mitosheet.user.db import get_user_field
-from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_UPGRADED_DATE,
-                                    UJ_MITOSHEET_PRO)
+from mitosheet.user.schemas import (
+    UJ_FEEDBACKS, UJ_MITOSHEET_LAST_UPGRADED_DATE, UJ_MITOSHEET_LAST_FIFTY_USAGES
+)
 
-def is_running_test() -> bool:
+def is_running_test():
     """
     A helper function that quickly returns if the current code is running 
     inside of a test, which is useful for making sure we don't generate 
@@ -31,7 +31,7 @@ def is_running_test() -> bool:
 
     return running_pytests or running_ci
 
-def is_on_kuberentes_mito() -> bool:
+def is_on_kuberentes_mito():
     """
     Returns True if the user is on Kuberentes Mito, on staging or on app
     """
@@ -39,16 +39,7 @@ def is_on_kuberentes_mito() -> bool:
     return user == 'jovyan'
 
 
-def is_pro() -> bool:
-    """
-    Helper function for returning if this is a
-    pro deployment of mito
-    """
-    is_pro = get_user_field(UJ_MITOSHEET_PRO)
-    return is_pro if is_pro is not None else False
-
-
-def is_local_deployment() -> bool:
+def is_local_deployment():
     """
     Helper function for figuring out if this a local deployment or a
     Mito server deployment
@@ -56,7 +47,7 @@ def is_local_deployment() -> bool:
     return not is_on_kuberentes_mito()  
 
 
-def should_upgrade_mitosheet() -> bool:
+def should_upgrade_mitosheet():
     """
     A helper function that calculates if a user should upgrade, which does so by 
     checking if the user has upgraded in the past 21 days (3 weeks), since this is
@@ -71,23 +62,30 @@ def should_upgrade_mitosheet() -> bool:
     if not is_local_deployment():
         return False
 
-    last_upgraded_date_stored = get_user_field(UJ_MITOSHEET_LAST_UPGRADED_DATE)
-    if last_upgraded_date_stored is None:
-        return False
-
-    mitosheet_last_upgraded_date = datetime.strptime(last_upgraded_date_stored, '%Y-%m-%d')
+    mitosheet_last_upgraded_date = datetime.strptime(get_user_field(UJ_MITOSHEET_LAST_UPGRADED_DATE), '%Y-%m-%d')
     return (datetime.now() - mitosheet_last_upgraded_date).days > 21
 
-def is_excel_import_enabled() -> bool:
+
+def should_display_feedback():
     """
-    Returns true if Python > 3.6 is installed, and Pandas > 0.25.0 is installed,
-    as this is when openpyxl works.
+    The user gives an initial piece of feedback when they first sign up
+    for Mito. Thus, all users have 1 piece of feedback. 
 
-    See here: https://pandas.pydata.org/pandas-docs/dev/whatsnew/v0.25.0.html
+    We then expect them to give feedback on days: 2, 7, 20, 35, 49 
+    of using the tool. We thus check the number of feedbacks they have
+    given to that point.
+
+    NOTE: as the user can submit feedback manually, this might be annoying
+    for some users, as they might get prompted after they submit feedback.
+    However, as we have never seen a user do this, we don't worry about it
+    for now.
     """
-    from mitosheet.saved_analyses.schema_utils import is_prev_version
+    num_feedbacks = len(get_user_field(UJ_FEEDBACKS))
+    num_days = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
 
-    python_version_valid = sys.version_info.minor > 6
-    pandas_version_valid = not is_prev_version(pd.__version__, '0.25.0')
+    return (num_feedbacks <= 1 and num_days >= 2) or \
+        (num_feedbacks <= 2 and num_days >= 7) or \
+        (num_feedbacks <= 3 and num_days >= 20) or \
+        (num_feedbacks <= 4 and num_days >= 35) or \
+        (num_feedbacks <= 5 and num_days >= 49)
 
-    return python_version_valid and pandas_version_valid
