@@ -18,9 +18,12 @@ from mitosheet.steps.initalize import execute_initialize_step
 from mitosheet.preprocessing import PREPROCESS_STEPS
 from mitosheet.utils import dfs_to_json, get_new_step_id
 from mitosheet.transpiler.transpile import transpile
-from mitosheet.user.user_utils import get_user_field
+from mitosheet.user import get_user_field
 from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
 from mitosheet.mito_analytics import log
+from mitosheet.user import (
+    UJ_INTENDED_BEHAVIOR, UJ_USER_EMAIL, UJ_RECEIVED_TOURS
+)
 
 class WidgetStateContainer():
     """
@@ -146,21 +149,21 @@ class WidgetStateContainer():
         """
         Returns the user_email from user.json
         """
-        return get_user_field('user_email')
+        return get_user_field(UJ_USER_EMAIL)
 
     @property
     def received_tours(self):
         """
         Returns the tours that the user has received
         """
-        return json.dumps(get_user_field('received_tours'))
+        return json.dumps(get_user_field(UJ_RECEIVED_TOURS))
 
     @property
     def intended_behavior(self):
         """
         Returns the intended_behavior of the user as inputted in the signup flow
         """
-        return json.dumps(get_user_field('intended_behavior'))
+        return json.dumps(get_user_field(UJ_INTENDED_BEHAVIOR))
 
     @property
     def step_data_list_json(self):
